"""Function for io operations
 
In Spring 2020, to demo how to build a Python project, this project was
created for the students in CS4900 senior seminar class. This module contains
the functions about input and output the prime nubmers into or from a csv file.
 
Example:
    python primeio.py
 
"""
 
__author__ = 'Lin Chen'
__version__ = 0.1
__email__ = 'lin.chen@ieee.org'
__status__ = 'Prototype'
 
import csv
 
def write_primes(prime_list, file_name):
    """Output a list of prime numbers into a csv file
 
    Args:
        prime_list (list): a list of prime numbers
        file_name (str): file name of a csv file
 
    Raises:
        IOError: if file is not able to be opened
 
    Examples:
        >>> write_primes([2, 3, 5, 7], 'output.csv')
 
    """
    with open(file_name, 'w') as csvfile:
        writter = csv.writer(csvfile, delimiter=',')
        writter.writerow(prime_list)
 
def read_primes(file_name):
    """Read a list of prime numbers from a csv file
 
    Args:
        file_name (str): file name of a csv file
 
    Raises:
        IOError: if file is not able to be read
 
    Examples:
        >>> l = read_primes('output.csv')
 
    """
    with open(file_name, newline='') as csvfile:
        reader = csv.reader(csvfile, delimiter=',')
        for row in reader:
            prime_list = []
            for field in row:
                prime_list.append(int(field))
            return prime_list



from setuptools import setup
 
with open('requirements.txt') as f:
    requirements = f.read().splitlines()
 
setup(
    name='linlangleyprime', # a unique name for PyPI
    version='0.3',
    description='Demo for building a Python project',
    author='Lin Chen',
    author_email='lin.chen@ieee.org',
    url='http://lin-chen-va.github.io',
    install_requires=requirements,
    packages=['primepackage', ], # packages and subpackages containing .py files
    package_dir={'':'src'}, # location to find the packages
    scripts=['src/generator',], # the executable files will be installed for user
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description=open('README.md').read(),
    classifiers=[
      'Development Status :: 4 - Beta',
      'Environment :: X11 Applications :: GTK',
      'Intended Audience :: End Users/Desktop',
      'Intended Audience :: Developers',
      'License :: OSI Approved :: GNU General Public License (GPL)',
      'Operating System :: POSIX :: Linux',
      'Programming Language :: Python',
      'Topic :: Desktop Environment',
      'Topic :: Text Processing :: Fonts'
      ],
)



"""Functions for prime numbers
 
In Spring 2020, to demo how to build a Python project, this project was
created for the students in CS4900 senior seminar class. This module contains
the functions about prime numbers.
 
Example:
    python primemodule.py
 
"""
 
__author__ = "Lin Chen"
__version__ = 0.1
__email__ = "lin.chen@ieee.org"
__status__ = "Prototype"
 
def is_prime(number):
    """Check if a number is a prime
 
    Args:
        number (int): integer number
 
    Return:
        boolean: true if n is a prime number, false otherwise
 
    Raises:
        ValueError: if n is not a natural number
 
    Examples:
        >>> b = is_prime(83)
 
    """
    if not isinstance(number, int):
        raise ValueError("Not an integer number")
 
    if number <= 0:
        raise ValueError("Not a natural number")
 
    if number == 1:
        return False
 
    for i in range(2, number):
        if number%i == 0:
            return False
 
    return True
 
def get_n_prime(num):
    """Get the fist num prime numbers
 
    Args:
        num (int): the number of the first prime numbers
 
    Return:
        list: a list of integer numbers
 
    Examples:
        >>> prime_list = get_n_prime(10)
 
    """
    current_num = 2
    count = 0
    prime_list = []
 
    while True:
        if is_prime(current_num):
            prime_list.append(current_num)
            count += 1
            if count == num:
                return prime_list
        current_num += 1
